.. :changelog:

History
-------

0.4.7dev (6.6.2013)
+++++++++++++++++++

 - Fixes of some of typos
 - Many changes to setup.py

0.4.2dev (05.06.2013)
+++++++++++++++++++

 - Merge with Allan Clark's pull request providing better API
 - Changed name from libpepa to pypepa where possible  
 - First package version, for now only for dev branch 
 - pypepa cli moved to pypepa.cli for a better packaging
 
 
